==> qtjambi-qml-debuginfo-macos-5.15.20.jar: sources/QtJambiQml/QQmlDebuggingEnabler_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmldebug.h>
#include <QtCore/QHash>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlDebuggingEnabler(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlDebuggingEnabler")
    QQmlDebuggingEnabler *_ptr = reinterpret_cast<QQmlDebuggingEnabler *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// destruct QQmlDebuggingEnabler
void __qt_destruct_QQmlDebuggingEnabler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlDebuggingEnabler")
    reinterpret_cast<QQmlDebuggingEnabler*>(ptr)->~QQmlDebuggingEnabler();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlDebuggingEnabler::connectToLocalDebugger(QString,QQmlDebuggingEnabler::StartMode)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_connectToLocalDebugger_1native_1cref_1QString_1QQmlDebuggingEnabler_1StartMode__Ljava_lang_String_2I)
(JNIEnv *__jni_env,
 jclass,
 jstring socketFileName0,
 jint mode1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::connectToLocalDebugger(QString,QQmlDebuggingEnabler::StartMode)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_socketFileName0 = qtjambi_cast<QString>(__jni_env, socketFileName0);
        QQmlDebuggingEnabler::StartMode __qt_mode1 = qtjambi_cast<QQmlDebuggingEnabler::StartMode>(__jni_env, mode1);
        __java_return_value = QQmlDebuggingEnabler::connectToLocalDebugger(__qt_socketFileName0, QQmlDebuggingEnabler::StartMode(__qt_mode1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::debuggerServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_debuggerServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::debuggerServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::debuggerServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::inspectorServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_inspectorServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::inspectorServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::inspectorServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::nativeDebuggerServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_nativeDebuggerServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::nativeDebuggerServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::nativeDebuggerServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::profilerServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_profilerServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::profilerServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::profilerServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::setServices(QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_setServices__Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass,
 jobject services0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::setServices(QStringList)")
    QtJambiScope __qtjambi_scope;
    QTJAMBI_TRY {
        const QStringList&  __qt_services0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, services0);
        QQmlDebuggingEnabler::setServices(__qt_services0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlDebuggingEnabler::startDebugConnector(QString,QVariantHash)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_startDebugConnector__Ljava_lang_String_2Ljava_util_Map_2)
(JNIEnv *__jni_env,
 jclass,
 jstring pluginName0,
 jobject configuration1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::startDebugConnector(QString,QVariantHash)")
    QtJambiScope __qtjambi_scope;
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_pluginName0 = qtjambi_cast<QString>(__jni_env, pluginName0);
        const QHash<QString, QVariant>&  __qt_configuration1 = qtjambi_cast<const QHash<QString, QVariant>& >(__jni_env, __qtjambi_scope, configuration1);
        __java_return_value = QQmlDebuggingEnabler::startDebugConnector(__qt_pluginName0, __qt_configuration1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::startTcpDebugServer(int,QQmlDebuggingEnabler::StartMode,QString)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_startTcpDebugServer_1native_1int_1QQmlDebuggingEnabler_1StartMode_1cref_1QString__IILjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jint port0,
 jint mode1,
 jstring hostName2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::startTcpDebugServer(int,QQmlDebuggingEnabler::StartMode,QString)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQmlDebuggingEnabler::StartMode __qt_mode1 = qtjambi_cast<QQmlDebuggingEnabler::StartMode>(__jni_env, mode1);
        QString  __qt_hostName2 = qtjambi_cast<QString>(__jni_env, hostName2);
        __java_return_value = QQmlDebuggingEnabler::startTcpDebugServer(static_cast<int>(port0), QQmlDebuggingEnabler::StartMode(__qt_mode1), __qt_hostName2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlDebuggingEnabler(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QQmlDebuggingEnabler>("QQmlDebuggingEnabler", "io/qt/qml/QQmlDebuggingEnabler");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQmlDebuggingEnabler, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlDebuggingEnabler);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QQmlDebuggingEnabler::StartMode>("QQmlDebuggingEnabler::StartMode", "io/qt/qml/QQmlDebuggingEnabler$StartMode");
// END: enums and flags
}

==> qtjambi-qml-debuginfo-macos-6.7.0.jar: sources/QtJambiQml/QQmlDebuggingEnabler_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtQml/qqmldebug.h>
#include <QtCore/QHash>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QQmlDebuggingEnabler(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QQmlDebuggingEnabler")
    QQmlDebuggingEnabler *_ptr = reinterpret_cast<QQmlDebuggingEnabler *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// destruct QQmlDebuggingEnabler
void __qt_destruct_QQmlDebuggingEnabler(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QQmlDebuggingEnabler")
    reinterpret_cast<QQmlDebuggingEnabler*>(ptr)->~QQmlDebuggingEnabler();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QQmlDebuggingEnabler::connectToLocalDebugger(QString,QQmlDebuggingEnabler::StartMode)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_connectToLocalDebugger_1native_1cref_1QString_1QQmlDebuggingEnabler_1StartMode__Ljava_lang_String_2I)
(JNIEnv *__jni_env,
 jclass,
 jstring socketFileName0,
 jint mode1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::connectToLocalDebugger(QString,QQmlDebuggingEnabler::StartMode)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_socketFileName0 = qtjambi_cast<QString>(__jni_env, socketFileName0);
        QQmlDebuggingEnabler::StartMode __qt_mode1 = qtjambi_cast<QQmlDebuggingEnabler::StartMode>(__jni_env, mode1);
        __java_return_value = QQmlDebuggingEnabler::connectToLocalDebugger(__qt_socketFileName0, QQmlDebuggingEnabler::StartMode(__qt_mode1));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::debuggerServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_debuggerServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::debuggerServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::debuggerServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::enableDebugging(bool)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_enableDebugging__Z)
(JNIEnv *__jni_env,
 jclass,
 jboolean printWarning0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::enableDebugging(bool)")
    QTJAMBI_TRY {
        QQmlDebuggingEnabler::enableDebugging(static_cast<bool>(printWarning0));
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlDebuggingEnabler::inspectorServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_inspectorServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::inspectorServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::inspectorServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::nativeDebuggerServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_nativeDebuggerServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::nativeDebuggerServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::nativeDebuggerServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::profilerServices()
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_profilerServices__)
(JNIEnv *__jni_env,
 jclass)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::profilerServices()")
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        QStringList __qt_return_value = QQmlDebuggingEnabler::profilerServices();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::setServices(QStringList)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_setServices__Ljava_util_Collection_2)
(JNIEnv *__jni_env,
 jclass,
 jobject services0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::setServices(QStringList)")
    QtJambiScope __qtjambi_scope;
    QTJAMBI_TRY {
        const QStringList&  __qt_services0 = qtjambi_cast<const QStringList& >(__jni_env, __qtjambi_scope, services0);
        QQmlDebuggingEnabler::setServices(__qt_services0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QQmlDebuggingEnabler::startDebugConnector(QString,QVariantHash)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_startDebugConnector__Ljava_lang_String_2Ljava_util_Map_2)
(JNIEnv *__jni_env,
 jclass,
 jstring pluginName0,
 jobject configuration1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::startDebugConnector(QString,QVariantHash)")
    QtJambiScope __qtjambi_scope;
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QString  __qt_pluginName0 = qtjambi_cast<QString>(__jni_env, pluginName0);
        const QHash<QString, QVariant>&  __qt_configuration1 = qtjambi_cast<const QHash<QString, QVariant>& >(__jni_env, __qtjambi_scope, configuration1);
        __java_return_value = QQmlDebuggingEnabler::startDebugConnector(__qt_pluginName0, __qt_configuration1);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QQmlDebuggingEnabler::startTcpDebugServer(int,QQmlDebuggingEnabler::StartMode,QString)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_qml_QQmlDebuggingEnabler_startTcpDebugServer_1native_1int_1QQmlDebuggingEnabler_1StartMode_1cref_1QString__IILjava_lang_String_2)
(JNIEnv *__jni_env,
 jclass,
 jint port0,
 jint mode1,
 jstring hostName2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QQmlDebuggingEnabler::startTcpDebugServer(int,QQmlDebuggingEnabler::StartMode,QString)")
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QQmlDebuggingEnabler::StartMode __qt_mode1 = qtjambi_cast<QQmlDebuggingEnabler::StartMode>(__jni_env, mode1);
        QString  __qt_hostName2 = qtjambi_cast<QString>(__jni_env, hostName2);
        __java_return_value = QQmlDebuggingEnabler::startTcpDebugServer(static_cast<int>(port0), QQmlDebuggingEnabler::StartMode(__qt_mode1), __qt_hostName2);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QQmlDebuggingEnabler(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QQmlDebuggingEnabler>("QQmlDebuggingEnabler", "io/qt/qml/QQmlDebuggingEnabler");
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QQmlDebuggingEnabler, {
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QQmlDebuggingEnabler);
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
    registerEnumTypeInfo<QQmlDebuggingEnabler::StartMode>("QQmlDebuggingEnabler::StartMode", "io/qt/qml/QQmlDebuggingEnabler$StartMode");
// END: enums and flags
}
